@@ -1,11 +1,11 @@
 """SPICE kernel pool module."""
 
-import logging
-
 import spiceypy as sp
 
+from ..misc import logger
 
-logging.basicConfig(format='[SPICE Pool] %(message)s')
+
+log_spice_pool, debug_spice_pool = logger('SPICE Pool')
 
 
 class MetaSPICEPool(type):
@@ -55,15 +55,15 @@ class MetaSPICEPool(type):
         return cls.remove(el)
 
     @staticmethod
-    def count():
+    def count() -> int:
         """Count the number of kernels in the pool."""
-        return sp.ktotal('ALL')
+        return int(sp.ktotal('ALL'))
 
     def get_pool(cls):
         """Get SPICE kernel pool files."""
-        return tuple([
+        return tuple(
             sp.kdata(i, 'ALL')[0] for i in range(cls.count())
-        ])
+        )
 
     def get_pool_hash(cls):
         """Get SPICE pool content hash."""
@@ -84,9 +84,9 @@ class MetaSPICEPool(type):
             cls.purge()
 
         if kernel in cls:
-            raise ValueError(f'Kernel `{kernel}` is not in the pool.')
+            raise ValueError(f'Kernel `{kernel}` is already in the pool.')
 
-        logging.debug('Add %s', kernel)
+        log_spice_pool.debug('Add %s', kernel)
         sp.furnsh(kernel)
 
     def remove(cls, kernel):
@@ -94,13 +94,13 @@ class MetaSPICEPool(type):
         if kernel not in cls:
             raise ValueError(f'Kernel `{kernel}` is not in the pool.')
 
-        logging.debug('Remove %s', kernel)
+        log_spice_pool.debug('Remove %s', kernel)
         sp.unload(kernel)
 
     @staticmethod
     def purge():
         """Purge the pool from all its content."""
-        logging.info('Empty the pool')
+        log_spice_pool.info('Empty the pool')
         sp.kclear()
 
 
